/**
 * InScript regular expression rules table for Sanskrit script
 * According to CDAC's "Enhanced InScript Keyboard Layout 5.2"
 * @author Junaid P V ([[user:Junaidpv]])
 * @date 2010-12-26
 * License: GPLv3
 */
var rules = [
['X', '', 'ँ'],
['x', '', 'ं'],
['_', '', 'ः'],
['D', '', 'अ'],
['E', '', 'आ'],
['F', '', 'इ'],
['R', '', 'ई'],
['G', '', 'उ'],
['T', '', 'ऊ'],
['\\+', '', 'ृ'],
['S', '', 'ए'],
['W', '', 'ऐ'],
['A', '', 'ओ'],
['Q', '', 'औ'],
['k', '', 'क'],
['K', '', 'ख'],
['i', '', 'ग'],
['I', '', 'घ'],
['U', '', 'ङ'],
['\\;', '', 'च'],
['\\:', '', 'छ'],
['p', '', 'ज'],
['P', '', 'झ'],
['\\}', '', 'ञ'],
["'", '', 'ट'],
['"', '', 'ठ'],
['\\[', '','ड'],
['\\{', '','ढ'],
['C', '', 'ण'],
['l', '', 'त'],
['L', '', 'थ'],
['o', '', 'द'],
['O', '', 'ध'],
['v', '', 'न'],
['h', '', 'प'],
['H', '', 'फ'],
['y', '', 'ब'],
['Y', '', 'भ'],
['c', '', 'म'],
['\\?', '','य'],
['j', '', 'र'],
['n', '', 'ल'],
['N', '', 'ळ'],
['b', '', 'व'],
['M', '', 'श'],
['\\<', '','ष'],
['m', '', 'स'],
['u', '', 'ह'],
['\\]', '','़'],
['e', '', 'ा'],
['f', '', 'ि'],
['r', '', 'ी'],
['g', '', 'ु'],
['t', '', 'ू'],
['\\=', '','ृ'],
['\\\\', '', 'ॄ'],
['s', '', 'े'],
['w', '', 'ै'],
['a', '', 'ो'],
['q', '', 'ौ'],
['d', '', '्'],
['\\|', '', 'ॠ'],
['/', '', 'य'],
['\\>', '', '।'],
['0', '','०'],
['1', '','१'],
['2', '', '२'],
['3', '', '३'],
['4', '', '४'],
['5', '', '५'],
['6', '', '६'],
['7', '', '७'],
['8', '', '८'],
['9', '', '९'],
['\\@', '', 'ॅ'],
['\\#', '','्र'],
['\\$', '','र्'],
['\\%', '','ज्ञ'],
['\\^', '','त्र'],
['\\&', '', 'क्ष'],
['\\*', '', 'श्र'],
['\\(', '', '\u200D'],
['\\)', '', '\u200C']
];

// Extended layout for InScript. Works in Firefox only
var rules_x = [
['F', '', 'ऌ'],
['\\>', '','ऽ'],
['X', '', 'ॐ'],
['e', '', '\0951'],
['d', '', '\u0952'],
['R', '', 'ॡ'],
['f', '', 'ॢ'],
['r', '', 'ॣ'],
['\\.', '', '॥'],
['\\@', '','ॅ'],
['4', '', '₹']
];

jQuery.narayam.addScheme( 'sa-inscript', {
	'namemsg': 'narayam-sa-inscript',
	'extended_keyboard': true,
	'lookbackLength': 0,
	'keyBufferLength': 0,
	'rules': rules,
	'rules_x': rules_x
} );